@@ -109,7 +109,7 @@ class CSVDoggo:
             elif key.startswith("csv_"):
                 kw[key[4:]] = kw.pop(key)
 
-        if kw.get("header", 0) < 0:
+        if kw.get("header", 0) == -1:
             kw.pop("header")
 
         if 'na_rep' in kw:
