@@ -110,13 +110,14 @@ class PandasDoggo:
         if path.endswith('.zip'):
             return 'zip'
 
-    def load(self, path, file_format=None, compression=None, *args, **kwargs):
+    def load(self, path, file_format=None, compression=None, request_payer='bucketowner', *args, **kwargs):
         """Load a file into a Pandas.DataFrame from local or s3 locations.
 
         :param path: required. Can be s3 or local s3 must be in `s3://` format - accepts `S3Location`
         :type path: str
         :param file_format: None. Autodetects from path, can be set to `csv` or `parquet` to explicitly force a format
         :param compression: optional, 'gzip', 'snappy' or None. Autodetects from path if path ends in `.gz`, `.gzip` or contains `.snappy`
+        :param request_payer: either 'bucketowner' (default) or 'requester' - who incurs the cost of said operation
         :param args: args to pass to the panda to load the file
         :param kwargs: kwargs to pass to the panda to load the file eg columns=['subset', 'of', 'columns']
         :return: Pandas.DataFrame
@@ -128,34 +129,34 @@ class PandasDoggo:
             raise ValueError(f'detected format:{format} is not recognized file format for load')
 
         if file_format == 'csv':
-            return self.load_csv(path, compression=compression, *args, **kwargs)
+            return self.load_csv(path, compression=compression, request_payer=request_payer, *args, **kwargs)
 
         elif file_format in ('parquet', 'pq'):
-            return self.load_parquet(path, compression=compression, *args, **kwargs)
+            return self.load_parquet(path, compression=compression, request_payer=request_payer, *args, **kwargs)
 
-    def load_csv(self, path, compression=None, *args, **kwargs):
+    def load_csv(self, path, compression=None, request_payer='bucketowner', *args, **kwargs):
         """alias for .load(path, format='csv')"""
         if 'chunksize' in kwargs:
             raise NotImplementedError("PandasDoggo does not support chunksize for loading data frames")
 
         compression = compression or self._extract_compression(path)
-        fm = FileDoggo(path, mode='rb', client=self.s3_client, compression=compression)
+        fm = FileDoggo(path, mode='rb', client=self.s3_client, compression=compression, request_payer=request_payer)
         with fm as f:
             df = pd.read_csv(f, *args, **kwargs)
 
         return df
 
-    def load_parquet(self, path, compression=None, *args, **kwargs):
+    def load_parquet(self, path, compression=None, request_payer='bucketowner', *args, **kwargs):
         """alias for .load(path, format='parquet')"""
 
         compression = compression or self._extract_compression(path)
-        fm = FileDoggo(path, mode='rb', client=self.s3_client, compression=compression)
+        fm = FileDoggo(path, mode='rb', client=self.s3_client, compression=compression, request_payer=request_payer)
         with fm as f:
             df = pd.read_parquet(f, engine='pyarrow', *args, **kwargs)
 
         return df
 
-    def save(self, df, path, file_format=None, compression=None, *args, **kwargs):
+    def save(self, df, path, file_format=None, compression=None, request_payer='bucketowner', *args, **kwargs):
         """Save a file into a Pandas.DataFrame from local or s3 locations.
 
         :param df: Data frame
@@ -164,6 +165,7 @@ class PandasDoggo:
         :type path: str
         :param file_format: 'None. Autodetects from path, can be set to `csv` or `parquet` to explicitly force a format
         :param compression: None. Supports gzip and snappy, autodetects from path if path ends in `.gz`, `.gzip` or contains `.snappy`
+        :param request_payer: either 'bucketowner' (default) or 'requester' - who incurs the cost of said operation
         :param args: args to pass to the panda to save the file
         :param kwargs: kwargs to pass to the panda to save the file eg index=None
         """
@@ -171,23 +173,23 @@ class PandasDoggo:
         file_format = file_format or self._extract_file_format(path)
 
         if file_format == 'csv':
-            return self.save_csv(df, path, compression, *args, **kwargs)
+            return self.save_csv(df, path, compression=compression, request_payer=request_payer, *args, **kwargs)
 
         elif file_format in ('parquet', 'pq'):
-            return self.save_parquet(df, path, compression, *args, **kwargs)
+            return self.save_parquet(df, path, compression=compression, request_payer=request_payer, *args, **kwargs)
 
-    def save_csv(self, df, path, compression=None, *args, **kwargs):
+    def save_csv(self, df, path, compression=None, request_payer='bucketowner', *args, **kwargs):
         """Alias for .save(df, format='csv')"""
         compression = compression or self._extract_compression(path)
-        fm = FileDoggo(path, mode='wb', client=self.s3_client, compression=compression)
+        fm = FileDoggo(path, mode='wb', client=self.s3_client, compression=compression, request_payer=request_payer)
         with fm as f:
             f.write(df.to_csv(None, *args, **kwargs).encode('utf-8'))
 
-    def save_parquet(self, df, path, compression=None, *args, **kwargs):
+    def save_parquet(self, df, path, compression=None, request_payer='bucketowner', *args, **kwargs):
         """Alias for .save(df, format='parquet')"""
 
         compression = compression or self._extract_compression(path)
-        fm = FileDoggo(path, mode='wb', client=self.s3_client, compression=compression)
+        fm = FileDoggo(path, mode='wb', client=self.s3_client, compression=compression, request_payer=request_payer)
         with fm as f:
             df.to_parquet(f, *args, **kwargs)
 
@@ -199,7 +201,8 @@ class PandasDoggo:
                          partition_columns,
                          partition_string="",
                          date_time_format="%Y-%m-%d_%H%M%S.%f",
-                         compression=None, *args, **kwargs):
+                         compression=None,
+                         request_payer='bucketowner', *args, **kwargs):
         """Save a data frame into multiple files, partitioned by the specified columns. The base path can be
         local file system, or S3.
 
@@ -221,6 +224,7 @@ class PandasDoggo:
         :param date_time_format: To minimise chances of overwrite the saved files contain the date time of when this
                 function was called, this param specifies the format of the date time
         :param compression: None. Supports gzip and snappy, autodetects from suffix if it ends in `.gz`, `.gzip` or contains `.snappy`
+        :param request_payer: either 'bucketowner' (default) or 'requester' - who incurs the cost of said operation
         :param args: args to pass to the panda to save the file
         :param kwargs: kwargs to pass to the panda to save the file eg index=None
         :return: Returns a full list of all file paths created, doesnt return base path as part of this
@@ -260,7 +264,7 @@ class PandasDoggo:
 
             # Save the dataframe
             self.save(group_df[[col for col in df.columns if col not in partition_columns]],
-                      file, compression=compression, *args, **kwargs)
+                      file, compression=compression, request_payer=request_payer, *args, **kwargs)
 
             # Add to the list to return
             paths.append(file)
@@ -288,7 +292,7 @@ This is written to treat local paths and s3 paths the same, returning a file lik
 """
     _connection = None
 
-    def __init__(self, path, mode='rb', is_s3=None, client=None, compression=None):
+    def __init__(self, path, mode='rb', is_s3=None, client=None, compression=None, request_payer='bucketowner'):
         """
         Creates the class
 
@@ -299,6 +303,7 @@ This is written to treat local paths and s3 paths the same, returning a file lik
         :type is_s3: bool
         :param client: optional `boto3.Session().Client('s3')` instance to use for s3 operations
         :param compression: None, 'gzip' or 'snappy'.
+        :param request_payer: either 'bucketowner' or 'requester' - who incurs the cost of said operation
         """
 
         self.buffer = BytesIO()
@@ -311,6 +316,8 @@ This is written to treat local paths and s3 paths the same, returning a file lik
         else:
             self.path = path
 
+        self.request_payer = request_payer
+
         self._client = client
         if compression in [None, 'gzip', 'snappy']:
             self.compression = compression
@@ -366,7 +373,8 @@ This is written to treat local paths and s3 paths the same, returning a file lik
     @AWSRetry.backoff(tries=5, delay=1, backoff=1, added_exceptions=['404'])
     def _read_s3(self):
 
-        self.client.download_fileobj(Bucket=self.path.bucket, Key=self.path.key, Fileobj=self.buffer)
+        self.client.download_fileobj(Bucket=self.path.bucket, Key=self.path.key, Fileobj=self.buffer,
+                                     ExtraArgs={'RequestPayer': self.request_payer})
         self.buffer.seek(0)
         return self.buffer
 
@@ -376,4 +384,5 @@ This is written to treat local paths and s3 paths the same, returning a file lik
             self.connection.close()  # flushes writing to gzip
 
         self.buffer.seek(0)
-        self.client.upload_fileobj(Bucket=self.path.bucket, Key=self.path.key, Fileobj=self.buffer)
+        self.client.upload_fileobj(Bucket=self.path.bucket, Key=self.path.key, Fileobj=self.buffer,
+                                   ExtraArgs={'RequestPayer': self.request_payer})
